@@ -46,7 +46,7 @@ from contextlib import contextmanager
 import msgpack
 import pylibmc
 
-VERSION = "0.3.3"
+VERSION = "0.3.4"
 
 class StarryError(Exception):
     def __init__(self, output):
@@ -239,6 +239,12 @@ class StarryServer(object):
                 while True:
                     try:
                         conn = listener.accept()
+                    except ConnectionError as e:
+                        self.logger.warn(f"Caught exception: {e.__doc__}({e})")
+                        continue
+                    except OSError as e:
+                        self.logger.warn(f"Caught exception: {e.__doc__}({e})")
+                        break
                     except Exception as e:
                         self.logger.warn(f"Caught exception: {e.__doc__}({e})")
                         continue
